@@ -6,9 +6,9 @@ cowbuilderroot="/home/neurodebian"
 buildplace="${cowbuilderroot}/build"
 
 # all currently supported dists
-allnddists="nd+debian-wheezy nd+debian-jessie nd+debian-stretch nd+debian-sid \
-            nd+ubuntu-precise nd+ubuntu-trusty nd+ubuntu-xenial nd+ubuntu-yakkety"
-alldists="$allnddists debian-wheezy debian-jessie debian-stretch debian-sid"
+allnddists="nd+debian-wheezy nd+debian-jessie nd+debian-stretch nd+debian-buster nd+debian-sid \
+            nd+ubuntu-precise nd+ubuntu-trusty nd+ubuntu-xenial nd+ubuntu-artful nd+ubuntu-bionic"
+alldists="$allnddists debian-wheezy debian-jessie debian-stretch debian-buster debian-sid"
 
 # default is debian
 aptcache="${cowbuilderroot}/debian_aptcache"
